@@ -36,7 +36,6 @@ static gchar *contributors[] = {
 	"J\xc3\xa9r\xc3\xb4me Bolliet",
 	"Andreas Bolsch",
 	"Dave Bordoley",
-	"Karsten Br\xC3\xA4" "ckelmann",
 	"Dario Bressanini",
 	"Emmanuel Briot",
 	"Stephen Browne",
@@ -155,6 +154,7 @@ static gchar *contributors[] = {
 	"Martin Kretzschmar",
 	"Andrew Kuchling",
 	"Stephan Kulow",
+	"Kaushal Kumar",
 	"Martynas Kunigelis",
 	"Tuomas Kuosmanen",
 	"Olof Kylander",
@@ -325,7 +325,6 @@ static gchar *contributors[] = {
 	"Vendu",
 	"Andrew Veliath",
 	"Luis Villa",
-	"Olav Vitters",
 	"Marius Vollmer",
 	"Shawn Wagner",
 	N_("Wanda The GNOME Fish"),
